use strict;
use Test::More;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );
use DE_EPAGES::Object::API::Factory qw (ExistsObjectByPath LoadRootObject LoadObjectByPath);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);
use DE_EPAGES::WebInterface::API::FakeRequest;

my $ROOTPATH = '/Test';
local $ENV{'EPAGES_TESTSITE'} = 'Store' unless defined $ENV{'EPAGES_TESTSITE'};

sub Main() {
    ConnectTestSite();
    ok( Init(), 'initialization' );

    my $FakeRequester = DE_EPAGES::WebInterface::API::FakeRequest->new;

    my $Shop = LoadObjectByPath('/Test/TestShop/');
    ok( $Shop->alias eq 'TestShop', 'Shop loaded' );

    my $RootCategory = $Shop->get('Categories');
    my $Cat = $RootCategory->child('MinimalCategory');

    my $URLsToTest = [$Shop->get('WebUrl'), $Cat->get('WebUrl')];

    foreach my $SiteURL (@$URLsToTest) {
        ok( visitSite($FakeRequester, $SiteURL) == 1, "$SiteURL contains language link." );
    }

    my $RegistrationPage = $Shop->get('WebUrl') . '&ViewAction=ViewRegistration';
    ok( visitSite($FakeRequester, $RegistrationPage) == 0, "$RegistrationPage shouldn't contain a language link." );
    $Shop->child('Languages')->child('de')->delete();

    foreach my $SiteURL (@$URLsToTest) {
        ok( visitSite($FakeRequester, $SiteURL) == 0, "$SiteURL shouldn't contain language link." );
    }

    ok( Cleanup(), 'cleanup');
    DisconnectSite();
    done_testing();
}

sub visitSite() {
    my ($FakeRequester, $SiteURL) = @_;
    my $Response = $FakeRequester->get( $SiteURL );
    die "Can't get $SiteURL: ".$Response->status_line unless $Response->is_success;
    my $SiteContent = $Response->content;
    my $ContainsLink = ($SiteContent =~ /<link rel="alternate" hreflang=".*?" href=".*?" >/);
    return $ContainsLink;
}

sub Init() {
    return 1 if LoadRootObject()->existsChild('Test') && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild('Object', {'Alias'=>'Test'});
    ImportObjects('import.xml', $ROOTPATH);
    return 1;
}

sub Cleanup() {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

RunScript(Sub=>\&Main, Debug=>1);