use Test::More tests => 9;
use strict;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::PdfConverter qw( ConvertXhtml2Pdf );

RunScript( Sub => sub {

    my $HtmlCode = '<html><head></head><body><p>blubb</p></body></html>';
    my $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'valid xhtml' );

    $HtmlCode = '<html><head></head><body><p>blubb</body></html>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'missing end tag' );

    $HtmlCode = '<html><head></head><body att=sddf><p>blubb</p></body></html>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'missing quotes' );

    $HtmlCode = '<html><head></head><body att=sddf"><p>blubb</p></body></html>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'odd number of qoutes (left one is missing)' );

    $HtmlCode = '<html><head></head><body att="sddf><p>blubb</p></body></html>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'odd number of qoutes (right one is missing)' );

    $HtmlCode = '<html><head></head><body att="sddf"><p>blubb</p></body>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), '</html> is missing' );

    $HtmlCode = '<head></head><body att="sddf"><p>blubb</p></body></html>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), '<html> is missing' );

    $HtmlCode = '<p>blubb</p>';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'valid xhtml snippet' );

    $HtmlCode = '<p>blubb';
    $Pdf = ConvertXhtml2Pdf($HtmlCode);
    ok( TestPdf($Pdf), 'missing end tag at xhtml snippet' );
});

sub TestPdf {
    my ($Pdf) = @_;
    return $Pdf =~ /^%PDF/ ? 1 : 0;
}
